@@ -149,8 +149,10 @@ def is_full_sun_synoptic_map(m, error=False):
 
 
 def _is_full_sun_car(m, error=False):
+    shape = m.data.shape
+
     dphi = m.meta['cdelt1']
-    phi = m.data.shape[1] * dphi
+    phi = shape[1] * dphi
     if not np.allclose(phi, 360, atol=0.1):
         if error:
             raise ValueError('Number of points in phi direction times '
@@ -159,7 +161,7 @@ def _is_full_sun_car(m, error=False):
         return False
 
     dtheta = m.meta['cdelt2']
-    theta = m.data.shape[0] * dtheta
+    theta = shape[0] * dtheta
     if not np.allclose(theta, 180, atol=0.1):
         if error:
             raise ValueError('Number of points in theta direction times '
@@ -170,17 +172,19 @@ def _is_full_sun_car(m, error=False):
 
 
 def _is_full_sun_cea(m, error=False):
+    shape = m.data.shape
+
     dphi = m.meta['cdelt1']
-    phi = m.data.shape[1] * dphi
+    phi = shape[1] * dphi
     if not np.allclose(phi, 360, atol=0.1):
         if error:
             raise ValueError('Number of points in phi direction times '
                              'CDELT1 must be close to 360 degrees. '
-                             f'Instead got {dphi} x {shape[0]} = {phi}')
+                             f'Instead got {dphi} x {shape[1]} = {phi}')
         return False
 
     dtheta = m.meta['cdelt2']
-    theta = m.data.shape[0] * dtheta * np.pi / 2
+    theta = shape[0] * dtheta * np.pi / 2
     if not np.allclose(theta, 180, atol=0.1):
         if error:
             raise ValueError('Number of points in theta direction times '
